@@ -58,7 +58,6 @@ class Poll(PollsAbstractModel):
     class Meta:
         verbose_name = u'Опрос Вконтакте'
         verbose_name_plural = u'Опросы Вконтакте'
-        ordering = ['created']
 
     remote_pk_field = 'poll_id'
 
@@ -100,7 +99,7 @@ class Poll(PollsAbstractModel):
         ct_model = User if owner_id > 0 else Group
         self.owner_content_type = ContentType.objects.get_for_model(ct_model)
         try:
-            self.owner_id = self.owner_content_type.get_object_for_this_type(remote_id=abs(owner_id)).id
+            self.owner_id = self.owner_content_type.get_object_for_this_type(remote_id=abs(owner_id)).pk
         except ObjectDoesNotExist:
             raise ValueError("Impossible to parse poll with unexisted owner %s, remote_id=%s" % (self.owner_content_type.model, owner_id))
 
@@ -121,7 +120,6 @@ class Answer(PollsAbstractModel):
     class Meta:
         verbose_name = u'Ответ опроса Вконтакте'
         verbose_name_plural = u'Ответы опросов Вконтакте'
-        ordering = ['remote_id']
 
     poll = models.ForeignKey(Poll, verbose_name=u'Опрос', related_name='answers')
     text = models.TextField(u'Текст ответа')
